#
# spec file for package newsflash
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _lto_cflags %{nil}
%define         appname io.gitlab.news_flash.NewsFlash
Name:           newsflash
Version:        3.3.5
Release:        1.1
Summary:        The spiritual successor to FeedReader
License:        GPL-3.0-only
URL:            https://gitlab.com/news-flash/news_flash_gtk
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  appstream-glib
BuildRequires:  cargo-packaging
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  glib-networking
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-gobject
BuildRequires:  update-desktop-files
BuildRequires:  xdg-utils
BuildRequires:  pkgconfig(blueprint-compiler)
BuildRequires:  pkgconfig(clapper-gtk-0.0)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(webkitgtk-6.0)
%ifarch aarch64
BuildRequires:  typelib(ClapperGtk)
%endif

%description
NewsFlash is a program designed to complement an already existing web-based RSS reader account.
It combines all the advantages of web based services like syncing across all your devices with everything you expect
from a modern desktop program: Desktop notifications, fast search and filtering, tagging, handy keyboard shortcuts
and having access to all your articles as long as you like.

%lang_package

%prep
%autosetup -a1

# show the actual version in the about page
sed -i "s|version: '0.0.0'|version: '%{version}'|g" meson.build

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file %{appname}

%find_lang %{name}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{appname}
%{_datadir}/applications/%{appname}.desktop
%{_iconsdir}/hicolor/scalable/apps/%{appname}.svg
%{_iconsdir}/hicolor/symbolic/apps/%{appname}-symbolic.svg
%{_datadir}/metainfo/%{appname}.appdata.xml

%files lang -f %{name}.lang

%changelog
* Tue Sep 24 2024 Richard Rahl <rrahl0@opensuse.org>
- update 3.3.5:
  * Fix listview selection regression
  * Fix headerbar sensitivity after 'mark all as read'
  * local RSS: prefer summary over media description
* Mon Jul 29 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 3.3.4:
  * Avoid re-downloaing non-expired favicons
  * Increase network-monitor changed signal timeout
- update to 3.3.3:
  * local rss: handle articles that are published with the same GUID by
    multiple feeds (eg planet.gnome.org)
  * local rss: use etags to skip downloading unchanged feeds
  * local rss: avoid writing unchanged articles to the database (feed-rs fix)
  * log running/successful database migrations
  * improve favicon and thumbnail download logic
  * fix drag and drop regression in feed list
  * article list: load queue to avoid data races
  * multiple ping urls for online checks
  * online check: try to reach backend server before falling back to generic urls
  * add back unread/starred database indices
  * re-enable full text search in article plain text
* Sat Jul 13 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 3.3.2:
  * Hotfix: use timeformat compatible with sqlite 3.42.0 in migration
* Fri Jul 12 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 3.3.1:
  * video player: mpris support
  * zoom controls in article menu
  * properly escape markup of empty feed list status
  * fix keyboard navigation article list with collapsed article view
  * favicon cache: cache and reuse gdk Textures to reduce memory consumption
  * local RSS: keep order of articles when no date is specified
  * article scraper: apply suggestions regarding libxml2 thread safety
  * article scraper: update full-text-rss config files
  * article scraper: replace images with single emoji in alt-text with unicode emoji
  * database: store timestamps with UTC timezone
  * database: reduce connection-pool size
- update to 3.3.0:
  * Video player based on libclapper
  * Performance: parallelize requests to services during sync as much as possible
  * miniflux: fix fetching a single feed after adding it
  * feed parsing: improve selecting the correct website link
  * Properly disconnect signals of listview rows
  * Ping: timeout faster than the 3s delay for network changes
  * Only show error badges if error count is greater than 0
  * Use gtk4 uri launcher instead of ashpd
  * Context menu to mark all articles as read
  * Add dialogs: fit long translated string into mobile form factor
- switch to changing version in spec file, removing show-actual-version.patch
* Fri May 10 2024 Richard Rahl <rrahl0@disroot.org>
- update to 3.2.0:
  * new per feed setting: scrap articles
  * local RSS: edit feed url
  * option to manually clean database
  * article list performance improvements
  * use adwaita adaptive dialogs
- show actual version in the app (show-actual-version.patch)
- improve on the spec file
- temporarily disable dep updating, as it breaks compile
* Wed Mar  6 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.6:
  * fix shortcuts blocking text input
  * fix zooming articles with ctrl + touch pad scroll
* Fri Mar  1 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.5:
  * activate running instance window when clicking launcher
- update to 3.1.4:
  * add cli option to subscribe to feed
  * open article in browser via mouse wheel click and 3 finger press
  * clear article list on mark all read
  * add shortcut to close an article
  * fix url overlay positioning
  * keep track of subscriptions and tags expansion state
  * fix mark all as read spinner
  * show shortcuts in menus
* Fri Feb 16 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.3:
  * fix appdata screenshots
- update to 3.1.2:
  * revert user agent change of 3.1.0
  * fix mark all as read when closing the app right afterwards
  * add share to clipboard
  * stop using trust DNS
  * limit concurrent HTTP calls to avoid DNS issues
  * FreshRSS: automatically add missing slash to Url on login
  * article scraper: add null checks in hope to prevent crashes
* Mon Feb 12 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.1:
  * fix pushing read updates to the API
* Mon Feb 12 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.0:
  * Fix tag context menu actions
  * Fix article scrolling on steam deck
  * Fix an error toast appearing right after successful login
  * Fix multiple instances of the image dialog spawning at the same time
  * Fix 12h/24h time format
  * Fix webview scrolling when zoomed via touch
  * Local RSS: Fix duplicate feeds after exporting and reimporting an OPML file
  * miniflux: support article enclosures
  * Mark articles as read when opening in external browser
  * Keep loaded articles when refreshing unread article list
  * Update the user agent
  * Add 'Zorin' article theme
  * Double check if Newsflash is offline by pinging an Url
  * Mark all read: only apply to articles that match current search term and list mode
  * Article View: remove selectabilty preference and make content selectable by default
  * Fetch content of a feed after adding it (if backend supports it)
  * Show fetch and parse issues of single feeds (if backend supports it)
  * Allow undoing mark all as read
* Fri Dec  8 2023 Richard Rahl <rrahl0@proton.me>
- initial packaging for openSUSE_Tumbleweed
